summaryrefslogtreecommitdiffstats
path: root/src/part/remoteLister.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/part/remoteLister.cpp')
-rw-r--r--src/part/remoteLister.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/part/remoteLister.cpp b/src/part/remoteLister.cpp
index b57fcfd..dc2d04f 100644
--- a/src/part/remoteLister.cpp
+++ b/src/part/remoteLister.cpp
@@ -70,9 +70,9 @@ namespace Filelight
setShowingDotFiles( true ); //stupid KDirLister API function names
setMainWindow( parent );
- //use TQT_SIGNAL(result(TDEIO::Job*)) instead and then use Job::error()
- connect( this, TQT_SIGNAL(completed()), TQT_SLOT(completed()) );
- connect( this, TQT_SIGNAL(canceled()), TQT_SLOT(canceled()) );
+ //use TQ_SIGNAL(result(TDEIO::Job*)) instead and then use Job::error()
+ connect( this, TQ_SIGNAL(completed()), TQ_SLOT(completed()) );
+ connect( this, TQ_SIGNAL(canceled()), TQ_SLOT(canceled()) );
//we do this non-recursively - it is the only way!
openURL( url );
@@ -97,7 +97,7 @@ namespace Filelight
//as usual KDE documentation didn't suggest I needed to do this at all
//I had to figure it out myself
// -- avoid crash
- TQTimer::singleShot( 0, this, TQT_SLOT(_completed()) );
+ TQTimer::singleShot( 0, this, TQ_SLOT(_completed()) );
}
void
@@ -105,7 +105,7 @@ namespace Filelight
{
debug() << "canceled: " << url().prettyURL() << endl;
- TQTimer::singleShot( 0, this, TQT_SLOT(_completed()) );
+ TQTimer::singleShot( 0, this, TQ_SLOT(_completed()) );
}
void